"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var Notification = android.app.Notification;
var Uri = android.net.Uri;
var View = android.view.View;
var util_1 = require("./util");
var MessagingListenerV2Impl = (function () {
    function MessagingListenerV2Impl(listener, inAppCampaignCache, pushCampaignCache, placesCampaignCache) {
        this.listener = listener;
        this.inAppCampaignCache = inAppCampaignCache;
        this.pushCampaignCache = pushCampaignCache;
        this.placesCampaignCache = placesCampaignCache;
    }
    MessagingListenerV2Impl.prototype.setInAppConfiguration = function (config) {
        this.inAppConfig = config;
    };
    MessagingListenerV2Impl.prototype.setPushConfiguration = function (config) {
        this.pushConfig = config;
    };
    MessagingListenerV2Impl.prototype.setPlacesConfiguration = function (config) {
        this.placesConfig = config;
    };
    MessagingListenerV2Impl.prototype.localyticsShouldShowInAppMessage = function (campaign) {
        this.inAppCampaignCache[campaign.getCampaignId()] = campaign;
        var nsCampaign = util_1.toInAppJSON(campaign);
        var shouldShow = true;
        if (this.inAppConfig != null) {
            if (this.inAppConfig.hasOwnProperty('shouldShow')) {
                shouldShow = this.inAppConfig.shouldShow;
            }
            if (this.inAppConfig.hasOwnProperty.has("diy") && this.inAppConfig.diy) {
                this.listener.localyticsDiyInAppMessage(nsCampaign);
                return false;
            }
        }
        this.listener.localyticsShouldShowInAppMessage(nsCampaign, shouldShow);
        return shouldShow;
    };
    MessagingListenerV2Impl.prototype.localyticsShouldDeeplink = function (deeplink) {
        return true;
    };
    MessagingListenerV2Impl.prototype.localyticsWillDisplayInAppMessage = function (campaign, configuration) {
        if (this.inAppConfig != null) {
            if (this.inAppConfig.hasOwnProperty('aspectRatio')) {
                configuration.setAspectRatio(this.inAppConfig.aspectRatio);
            }
            if (this.inAppConfig.hasOwnProperty('backgroundAlpha')) {
                configuration.setBackgroundAlpha(this.inAppConfig.backgroundAlpha);
            }
            if (this.inAppConfig.hasOwnProperty('bannerOffsetDps')) {
                configuration.setBannerOffsetDps(this.inAppConfig.bannerOffsetDps);
            }
            if (this.inAppConfig.hasOwnProperty('dismissButtonLocation')) {
                var location_1 = this.inAppConfig.dismissButtonLocation;
                configuration.setDismissButtonLocation(util_1.toLocation(location_1));
            }
            if (this.inAppConfig.hasOwnProperty('dismissButtonHidden')) {
                var hidden = this.inAppConfig.dismissButtonHidden;
                configuration.setDismissButtonVisibility(hidden ? View.GONE : View.VISIBLE);
            }
        }
        this.listener.localyticsWillDisplayInAppMessage(util_1.toInAppJSON(campaign));
        return configuration;
    };
    MessagingListenerV2Impl.prototype.localyticsDidDisplayInAppMessage = function () {
        this.listener.localyticsDidDisplayInAppMessage();
    };
    MessagingListenerV2Impl.prototype.localyticsWillDismissInAppMessage = function () {
        this.listener.localyticsWillDismissInAppMessage();
    };
    MessagingListenerV2Impl.prototype.localyticsDidDismissInAppMessage = function () {
        this.listener.localyticsDidDismissInAppMessage();
    };
    MessagingListenerV2Impl.prototype.localyticsShouldDelaySessionStartInAppMessages = function () {
        var shouldDelay = false;
        if (this.inAppConfig != null && this.inAppConfig.hasOwnProperty('delaySessionStart')) {
            shouldDelay = this.inAppConfig.delaySessionStart;
        }
        this.listener.localyticsShouldDelaySessionStartInAppMessages(shouldDelay);
        return shouldDelay;
    };
    MessagingListenerV2Impl.prototype.localyticsShouldShowPushNotification = function (campaign) {
        this.pushCampaignCache[campaign.getCampaignId()] = campaign;
        var shouldShow = true;
        var nsCampaign = util_1.toPushJSON(campaign);
        if (this.pushConfig != null) {
            if (this.pushConfig.hasOwnProperty('shouldShow')) {
                shouldShow = this.pushConfig.shouldShow;
            }
            if (this.pushConfig.hasOwnProperty('diy') && this.pushConfig.diy) {
                this.listener.localyticsDiyPushNotification(nsCampaign);
                return false;
            }
        }
        this.listener.localyticsShouldShowPushNotification(nsCampaign, shouldShow);
        return shouldShow;
    };
    MessagingListenerV2Impl.prototype.localyticsWillShowPushNotification = function (builder, campaign) {
        if (this.pushConfig != null) {
            this.updateNotification(builder, this.pushConfig);
        }
        this.listener.localyticsWillShowPushNotification(util_1.toPushJSON(campaign));
        return builder;
    };
    MessagingListenerV2Impl.prototype.localyticsShouldShowPlacesPushNotification = function (campaign) {
        this.placesCampaignCache[campaign.getCampaignId()] = campaign;
        var shouldShow = true;
        var nsCampaign = util_1.toPlacesJSON(campaign);
        if (this.placesConfig != null) {
            if (this.placesConfig.hasOwnProperty('shouldShow')) {
                shouldShow = this.placesConfig.shouldShow;
            }
            if (this.placesConfig.hasOwnProperty('diy') && this.placesConfig.diy) {
                this.listener.localyticsDiyPlacesPushNotification(nsCampaign);
                return false;
            }
        }
        this.listener.localyticsShouldShowPlacesPushNotification(nsCampaign, shouldShow);
        return shouldShow;
    };
    MessagingListenerV2Impl.prototype.localyticsWillShowPlacesPushNotification = function (builder, campaign) {
        if (this.placesConfig != null) {
            this.updateNotification(builder, this.placesConfig);
        }
        this.listener.localyticsWillShowPlacesPushNotification(util_1.toPlacesJSON(campaign));
        return builder;
    };
    MessagingListenerV2Impl.prototype.updateNotification = function (builder, config) {
        if (config.hasOwnProperty('category')) {
            builder.setCategory(config.category);
        }
        if (config.hasOwnProperty('color')) {
            builder.setColor(config.color);
        }
        if (config.hasOwnProperty('contentInfo')) {
            builder.setContentInfo(config.contentInfo);
        }
        if (config.hasOwnProperty('contentTitle')) {
            builder.setContentTitle(config.contentTitle);
        }
        if (config.hasOwnProperty('defaults')) {
            var defaultsArray = config.defaults;
            if (defaultsArray.indexOf('all') > -1) {
                builder.setDefaults(Notification.DEFAULT_ALL);
            }
            else {
                var defaults = 0;
                if (defaultsArray.indexOf('lights') > -1) {
                    defaults = defaults | Notification.DEFAULT_LIGHTS;
                }
                if (defaultsArray.indexOf('sound') > -1) {
                    defaults = defaults | Notification.DEFAULT_SOUND;
                }
                if (defaultsArray.indexOf('vibrate') > -1) {
                    defaults = defaults | Notification.DEFAULT_VIBRATE;
                }
                builder.setDefaults(defaults);
            }
        }
        if (config.hasOwnProperty('priority')) {
            builder.setPriority(config.priority);
        }
        if (config.hasOwnProperty('sound')) {
            builder.setSound(Uri.parse(config.sound));
        }
        if (config.hasOwnProperty('vibrate')) {
            builder.setVibrate(config.vibrate);
        }
        return builder;
    };
    MessagingListenerV2Impl = __decorate([
        Interfaces([com.localytics.android.MessagingListenerV2]),
        __metadata("design:paramtypes", [Object, Array,
            Array,
            Array])
    ], MessagingListenerV2Impl);
    return MessagingListenerV2Impl;
}());
exports.MessagingListenerV2Impl = MessagingListenerV2Impl;
//# sourceMappingURL=messagingListener.js.map