"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var localyticsNamespace = com.localytics.android;
var Localytics = localyticsNamespace.Localytics;
var JavaCircularRegion = localyticsNamespace.CircularRegion;
exports.JavaCircularRegion = JavaCircularRegion;
var JavaInAppCampaign = localyticsNamespace.InAppCampaign;
exports.JavaInAppCampaign = JavaInAppCampaign;
var JavaInboxCampaign = localyticsNamespace.InboxCampaign;
exports.JavaInboxCampaign = JavaInboxCampaign;
var JavaPlacesCampaign = localyticsNamespace.PlacesCampaign;
exports.JavaPlacesCampaign = JavaPlacesCampaign;
var JavaPushCampaign = localyticsNamespace.PushCampaign;
exports.JavaPushCampaign = JavaPushCampaign;
var JavaRegion = localyticsNamespace.Region;
function toHashMap(obj) {
    var node = new java.util.HashMap();
    for (var property in obj) {
        if (obj.hasOwnProperty(property)) {
            if (obj[property] != null) {
                switch (typeof obj[property]) {
                    case 'object':
                        node.put(property, toHashMap(obj[property]));
                        break;
                    case 'boolean':
                        node.put(property, java.lang.Boolean.valueOf(obj[property]));
                        break;
                    case 'number':
                        if (Number(obj[property]) === obj[property] && obj[property] % 1 === 0)
                            node.put(property, java.lang.Long.valueOf(obj[property]));
                        else
                            node.put(property, java.lang.Double.valueOf(obj[property]));
                        break;
                    case 'string':
                        node.put(property, java.lang.String.valueOf(obj[property]));
                        break;
                }
            }
        }
    }
    return node;
}
exports.toHashMap = toHashMap;
function toJsObject(javaObj) {
    var node = {};
    var iterator = javaObj.entrySet().iterator();
    while (iterator.hasNext()) {
        var item = iterator.next();
        switch (item.getClass().getName()) {
            case 'java.util.HashMap':
                node[item.getKey()] = toJsObject(item.getValue());
                break;
            case 'java.lang.String':
                node[item.getKey()] = String(item.getValue());
                break;
            case 'java.lang.Boolean':
                node[item.getKey()] = Boolean(String(item.getValue()));
                break;
            case 'java.lang.Long':
            case 'java.lang.Double':
                node[item.getKey()] = Number(String(item.getValue()));
                break;
        }
        node[item.getKey()] = item.getValue();
    }
    return node;
}
exports.toJsObject = toJsObject;
function toCircularRegionJSON(region) {
    return {
        uniqueId: region.getUniqueId(),
        latitude: region.getLatitude(),
        longitude: region.getLongitude(),
        name: region.getName(),
        type: region.getType(),
        attributes: toJsObject(region.getAttributes())
    };
}
exports.toCircularRegionJSON = toCircularRegionJSON;
function toInboxJSON(campaign) {
    var creativeFilePath = campaign.getCreativeFilePath();
    var thumbnailUri = campaign.getThumbnailUri();
    return {
        campaignId: campaign.getCampaignId(),
        name: campaign.getName(),
        attributes: toJsObject(campaign.getAttributes()),
        creativeFilePath: creativeFilePath != null ? creativeFilePath.toString() : '',
        read: campaign.isRead(),
        title: campaign.getTitle(),
        sortOrder: campaign.getSortOrder(),
        receivedDate: (campaign.getReceivedDate().getTime() / 1000),
        summary: campaign.getSummary(),
        thumbnailUrl: thumbnailUri != null ? thumbnailUri.toString() : '',
        hasCreative: campaign.hasCreative(),
        deeplink: campaign.getDeepLinkUrl(),
        isPushToInboxCampaign: campaign.isPushToInboxCampaign(),
        isVisible: campaign.isVisible(),
        deleted: campaign.isDeleted()
    };
}
exports.toInboxJSON = toInboxJSON;
function toInAppJSON(campaign) {
    var creativeFilePath = campaign.getCreativeFilePath();
    return {
        campaignId: campaign.getCampaignId(),
        name: campaign.getName(),
        attributes: toJsObject(campaign.getAttributes()),
        creativeFilePath: creativeFilePath != null ? creativeFilePath.toString() : '',
        aspectRatio: campaign.getAspectRatio(),
        bannerOffsetDps: campaign.getOffset(),
        backgroundAlpha: campaign.getBackgroundAlpha(),
        displayLocation: campaign.getDisplayLocation(),
        dismissButtonHidden: campaign.isDismissButtonHidden(),
        dismissButtonLocation: Localytics.InAppMessageDismissButtonLocation.RIGHT.equals(campaign.getDismissButtonLocation()) ? 'right' : 'left',
        eventName: campaign.getEventName(),
        eventAttributes: toJsObject(campaign.getEventAttributes())
    };
}
exports.toInAppJSON = toInAppJSON;
function toPushJSON(campaign) {
    return {
        campaignId: campaign.getCampaignId(),
        name: campaign.getName(),
        attributes: toJsObject(campaign.getAttributes()),
        creativeId: campaign.getCreativeId(),
        creativeType: campaign.getCreativeType(),
        message: campaign.getMessage(),
        title: campaign.getTitle(),
        soundFilename: campaign.getSoundFilename(),
        attachmentUrl: campaign.getAttachmentUrl()
    };
}
exports.toPushJSON = toPushJSON;
function toPlacesJSON(campaign) {
    return {
        campaignId: campaign.getCampaignId(),
        name: campaign.getName(),
        attributes: toJsObject(campaign.getAttributes()),
        creativeId: campaign.getCreativeId(),
        creativeType: campaign.getCreativeType(),
        message: campaign.getMessage(),
        title: campaign.getTitle(),
        soundFilename: campaign.getSoundFilename(),
        attachmentUrl: campaign.getAttachmentUrl(),
        region: this.toCircularRegionJSON(campaign.getRegion()),
        triggerEvent: JavaRegion.Event.ENTER.equals(campaign.getTriggerEvent()) ? 'enter' : 'exit'
    };
}
exports.toPlacesJSON = toPlacesJSON;
function toCircularRegion(circularRegion) {
    return new JavaCircularRegion.Builder()
        .setUniqueId(circularRegion.uniqueId)
        .build();
}
exports.toCircularRegion = toCircularRegion;
function toEvent(event) {
    if (event === 'enter') {
        return JavaRegion.Event.ENTER;
    }
    else {
        return JavaRegion.Event.EXIT;
    }
}
exports.toEvent = toEvent;
function toLocation(location) {
    if (location === 'left') {
        return Localytics.InAppMessageDismissButtonLocation.LEFT;
    }
    else {
        return Localytics.InAppMessageDismissButtonLocation.RIGHT;
    }
}
exports.toLocation = toLocation;
function fromLocation(location) {
    switch (location) {
        case Localytics.InAppMessageDismissButtonLocation.LEFT:
            return 'left';
        default:
            return 'right';
    }
}
exports.fromLocation = fromLocation;
//# sourceMappingURL=util.js.map