"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var application = require("tns-core-modules/application");
var Log = android.util.Log;
var View = android.view.View;
var util_1 = require("./android/util");
var messagingListener_1 = require("./android/messagingListener");
var localyticsNamespace = com.localytics.android;
var JavaInboxRefreshListener = localyticsNamespace.InboxRefreshListener;
var Localytics = localyticsNamespace.Localytics;
var JavaRegion = localyticsNamespace.Region;
var JavaAnalyticsListener = localyticsNamespace.AnalyticsListener;
var LocalyticsAndroid = (function () {
    function LocalyticsAndroid() {
    }
    LocalyticsAndroid.integrate = function () {
        Localytics.integrate(application.android.context);
        Localytics.setInAppMessageDisplayActivity(application.android.startActivity);
    };
    LocalyticsAndroid.autoIntegrate = function () {
        Localytics.autoIntegrate(application.android.context);
        Localytics.setInAppMessageDisplayActivity(application.android.startActivity);
    };
    LocalyticsAndroid.upload = function () {
        Localytics.upload();
    };
    LocalyticsAndroid.pauseDataUploading = function (pause) {
        Localytics.pauseDataUploading(pause);
    };
    LocalyticsAndroid.openSession = function () {
        Localytics.openSession();
    };
    LocalyticsAndroid.closeSession = function () {
        Localytics.closeSession();
    };
    LocalyticsAndroid.setOptedOut = function (enabled) {
        Localytics.setOptedOut(enabled);
    };
    LocalyticsAndroid.isOptedOut = function () {
        return Localytics.isOptedOut();
    };
    LocalyticsAndroid.setPrivacyOptedOut = function (enabled) {
        Localytics.setPrivacyOptedOut(enabled);
    };
    LocalyticsAndroid.isPrivacyOptedOut = function () {
        return Localytics.isPrivacyOptedOut();
    };
    LocalyticsAndroid.tagEvent = function (event, attributes, customerValueIncrease) {
        if (customerValueIncrease === void 0) { customerValueIncrease = 0; }
        Localytics.tagEvent(event, attributes ? util_1.toHashMap(attributes) : null, customerValueIncrease);
    };
    LocalyticsAndroid.tagPurchased = function (itemName, itemId, itemType, itemPrice, attributes) {
        Localytics.tagPurchased(itemName, itemId, itemType, itemPrice, attributes ? util_1.toHashMap(attributes) : null);
    };
    LocalyticsAndroid.tagAddedToCart = function (itemName, itemId, itemType, itemPrice, attributes) {
        Localytics.tagAddedToCart(itemName, itemId, itemType, itemPrice, attributes ? util_1.toHashMap(attributes) : null);
    };
    LocalyticsAndroid.tagStartedCheckout = function (totalPrice, itemCount, attributes) {
        Localytics.tagStartedCheckout(totalPrice, itemCount, attributes ? util_1.toHashMap(attributes) : null);
    };
    LocalyticsAndroid.tagCompletedCheckout = function (totalPrice, itemCount, attributes) {
        Localytics.tagCompletedCheckout(totalPrice, itemCount, attributes ? util_1.toHashMap(attributes) : null);
    };
    LocalyticsAndroid.tagContentViewed = function (contentName, contentId, contentType, attributes) {
        Localytics.tagContentViewed(contentName, contentId, contentType, attributes ? util_1.toHashMap(attributes) : null);
    };
    LocalyticsAndroid.tagSearched = function (queryText, contentType, resultCount, attributes) {
        Localytics.tagSearched(queryText, contentType, resultCount, attributes ? util_1.toHashMap(attributes) : null);
    };
    LocalyticsAndroid.tagShared = function (contentName, contentId, contentType, methodName, attributes) {
        Localytics.tagShared(contentName, contentId, contentType, methodName, attributes ? util_1.toHashMap(attributes) : null);
    };
    LocalyticsAndroid.tagContentRated = function (contentName, contentId, contentType, rating, attributes) {
        Localytics.tagContentRated(contentName, contentId, contentType, rating, attributes ? util_1.toHashMap(attributes) : null);
    };
    LocalyticsAndroid.tagCustomerRegistered = function (customer, methodName, attributes) {
        Localytics.tagCustomerRegistered(customer, methodName, attributes ? util_1.toHashMap(attributes) : null);
    };
    LocalyticsAndroid.tagCustomerLoggedIn = function (customer, methodName, attributes) {
        Localytics.tagCustomerLoggedIn(customer, methodName, attributes ? util_1.toHashMap(attributes) : null);
    };
    LocalyticsAndroid.tagCustomerLoggedOut = function (attributes) {
        Localytics.tagCustomerLoggedOut(attributes ? util_1.toHashMap(attributes) : null);
    };
    LocalyticsAndroid.tagInvited = function (methodName, attributes) {
        Localytics.tagInvited(methodName, attributes ? util_1.toHashMap(attributes) : null);
    };
    LocalyticsAndroid.tagInAppImpression = function (campaignId, action) {
        var campaign = LocalyticsAndroid.inAppCampaignCache[campaignId];
        if (campaign != null) {
            if (action === 'click') {
                Localytics.tagInAppImpression(campaign, Localytics.ImpressionType.CLICK);
            }
            else if (action === 'dismiss') {
                Localytics.tagInAppImpression(campaign, Localytics.ImpressionType.DISMISS);
            }
            else {
                Localytics.tagInAppImpression(campaign, action);
            }
        }
        else {
            Log.i(LocalyticsAndroid.LOG_TAG, "Call to tagInAppImpression failed; Campaign couldn't be found for campaign ID " + campaignId);
            throw new Error("Campaign couldn't be found for campaign ID " + campaignId);
        }
    };
    LocalyticsAndroid.tagInboxImpression = function (campaignId, action) {
        var campaign = LocalyticsAndroid.inboxCampaignCache[campaignId];
        if (campaign != null) {
            if (action === 'click') {
                Localytics.tagInboxImpression(campaign, Localytics.ImpressionType.CLICK);
            }
            else if (action === 'dismiss') {
                Localytics.tagInboxImpression(campaign, Localytics.ImpressionType.DISMISS);
            }
            else {
                Localytics.tagInboxImpression(campaign, action);
            }
        }
        else {
            Log.i(LocalyticsAndroid.LOG_TAG, "Call to tagInboxImpression failed; Campaign couldn't be found for campaign ID " + campaignId);
            throw new Error("Campaign couldn't be found for campaign ID " + campaignId);
        }
    };
    LocalyticsAndroid.tagPushToInboxImpression = function (campaignId, success) {
        var campaign = LocalyticsAndroid.inboxCampaignCache[campaignId];
        if (campaign != null) {
            Localytics.tagPushToInboxImpression(campaign);
        }
        else {
            Log.i(LocalyticsAndroid.LOG_TAG, "Call to tagPushToInboxImpression failed; Campaign couldn't be found for campaign ID " + campaignId);
            throw new Error("Campaign couldn't be found for campaign ID " + campaignId);
        }
    };
    LocalyticsAndroid.tagPlacesPushReceived = function (campaignId) {
        var campaign = LocalyticsAndroid.placesCampaignCache[campaignId];
        if (campaign != null) {
            Localytics.tagPlacesPushReceived(campaign);
        }
        else {
            Log.i(LocalyticsAndroid.LOG_TAG, "Call to tagPlacesPushReceived failed; Campaign couldn't be found for campaign ID " + campaignId);
            throw new Error("Campaign couldn't be found for campaign ID " + campaignId);
        }
    };
    LocalyticsAndroid.tagPlacesPushOpened = function (campaignId, action) {
        var campaign = LocalyticsAndroid.placesCampaignCache[campaignId];
        if (campaign != null) {
            Localytics.tagPlacesPushOpened(campaign);
        }
        else {
            Log.i(LocalyticsAndroid.LOG_TAG, "Call to tagPlacesPushOpened failed; Campaign couldn't be found for campaign ID " + campaignId);
            throw new Error("Campaign couldn't be found for campaign ID " + campaignId);
        }
    };
    LocalyticsAndroid.tagScreen = function (screen) {
        Localytics.tagScreen(screen);
    };
    LocalyticsAndroid.setCustomDimension = function (index, value) {
        Localytics.setCustomDimension(index, value);
    };
    LocalyticsAndroid.getCustomDimension = function (index) {
        return Localytics.getCustomDimension(index);
    };
    LocalyticsAndroid.setAnalyticsListener = function (listener) {
        LocalyticsAndroid.analyticsListener = new JavaAnalyticsListener({
            localyticsSessionWillOpen: function (isFirst, isUpgrade, isResume) {
                listener.localyticsSessionWillOpen(isFirst, isUpgrade, isResume);
            },
            localyticsSessionDidOpen: function (isFirst, isUpgrade, isResume) {
                listener.localyticsSessionDidOpen(isFirst, isUpgrade, isResume);
            },
            localyticsSessionWillClose: function () {
                listener.localyticsSessionWillClose();
            },
            localyticsDidTagEvent: function (eventName, attributes, customerValueIncrease) {
                listener.localyticsDidTagEvent(eventName, util_1.toJsObject(attributes), customerValueIncrease);
            }
        });
        Localytics.setAnalyticsListener(LocalyticsAndroid.analyticsListener);
    };
    LocalyticsAndroid.removeAnalyticsListener = function () {
        LocalyticsAndroid.analyticsListener = null;
        Localytics.setAnalyticsListener(null);
    };
    LocalyticsAndroid.setProfileAttribute = function (name, value, scope) {
        Localytics.setProfileAttribute(name, value, scope === 'org' ? Localytics.ProfileScope.ORGANIZATION : Localytics.ProfileScope.APPLICATION);
    };
    LocalyticsAndroid.addProfileAttributesToSet = function (name, value, scope) {
        Localytics.addProfileAttributesToSet(name, value, scope === 'org' ? Localytics.ProfileScope.ORGANIZATION : Localytics.ProfileScope.APPLICATION);
    };
    LocalyticsAndroid.removeProfileAttributesFromSet = function (name, value, scope) {
        Localytics.removeProfileAttributesFromSet(name, value, scope === 'org' ? Localytics.ProfileScope.ORGANIZATION : Localytics.ProfileScope.APPLICATION);
    };
    LocalyticsAndroid.incrementProfileAttribute = function (name, value, scope) {
        Localytics.incrementProfileAttribute(name, value, scope === 'org' ? Localytics.ProfileScope.ORGANIZATION : Localytics.ProfileScope.APPLICATION);
    };
    LocalyticsAndroid.decrementProfileAttribute = function (name, value, scope) {
        Localytics.decrementProfileAttribute(name, value, scope === 'org' ? Localytics.ProfileScope.ORGANIZATION : Localytics.ProfileScope.APPLICATION);
    };
    LocalyticsAndroid.deleteProfileAttribute = function (name, scope) {
        Localytics.deleteProfileAttribute(name, scope === 'org' ? Localytics.ProfileScope.ORGANIZATION : Localytics.ProfileScope.APPLICATION);
    };
    LocalyticsAndroid.setCustomerEmail = function (email) {
        Localytics.setCustomerEmail(email);
    };
    LocalyticsAndroid.setCustomerFirstName = function (firstName) {
        Localytics.setCustomerFirstName(firstName);
    };
    LocalyticsAndroid.setCustomerLastName = function (lastName) {
        Localytics.setCustomerLastName(lastName);
    };
    LocalyticsAndroid.setCustomerFullName = function (fullName) {
        Localytics.setCustomerFullName(fullName);
    };
    LocalyticsAndroid.getIdentifier = function (key) {
        return Localytics.getIdentifier(key);
    };
    LocalyticsAndroid.setIdentifier = function (key, value) {
        Localytics.setIdentifier(key, value);
    };
    LocalyticsAndroid.getCustomerId = function () {
        return Localytics.getCustomerId();
    };
    LocalyticsAndroid.setCustomerId = function (id) {
        Localytics.setCustomerId(id);
    };
    LocalyticsAndroid.setCustomerIdWithPrivacyOptedOut = function (id, enabled) {
        Localytics.setCustomerIdWithPrivacyOptedOut(id, enabled);
    };
    LocalyticsAndroid.setLocation = function (latitude, longitude) {
        var location = new android.location.Location('');
        location.setLatitude(latitude);
        location.setLongitude(longitude);
        Localytics.setLocation(location);
    };
    LocalyticsAndroid.registerPush = function () {
        Localytics.registerPush();
    };
    LocalyticsAndroid.setPushToken = function (pushToken) {
        Localytics.setPushRegistrationId(pushToken);
    };
    LocalyticsAndroid.getPushToken = function () {
        return Localytics.getPushRegistrationId();
    };
    LocalyticsAndroid.setPushMessageConfiguration = function (config) {
        if (LocalyticsAndroid.messagingListener != null) {
            LocalyticsAndroid.messagingListener.setPushConfiguration(config);
        }
        else {
            Log.i(LocalyticsAndroid.LOG_TAG, 'Call to setPushMessagingConfiguration failed; Messaging Listener is null. Call setMessagingListener before setting configuration');
            throw new Error('Messaging Listener is null. Call setMessagingListener before setting configuration');
        }
    };
    LocalyticsAndroid.setTestModeEnabled = function (enabled) {
        Localytics.setTestModeEnabled(enabled);
    };
    LocalyticsAndroid.isTestModeEnabled = function () {
        return Localytics.isTestModeEnabled();
    };
    LocalyticsAndroid.setInAppMessageDismissButtonImageWithName = function (imageName) {
    };
    LocalyticsAndroid.setInAppMessageDismissButtonHidden = function (hidden) {
        Localytics.setInAppMessageDismissButtonVisibility(hidden ? View.GONE : View.VISIBLE);
    };
    LocalyticsAndroid.setInAppMessageDismissButtonLocation = function (buttonLocation) {
        Localytics.setInAppMessageDismissButtonLocation(util_1.toLocation(buttonLocation));
    };
    LocalyticsAndroid.getInAppMessageDismissButtonLocation = function () {
        return util_1.fromLocation(Localytics.getInAppMessageDismissButtonLocation());
    };
    LocalyticsAndroid.triggerInAppMessage = function (triggerName, attributes) {
        Localytics.triggerInAppMessage(triggerName, util_1.toHashMap(attributes));
    };
    LocalyticsAndroid.triggerInAppMessagesForSessionStart = function () {
        Localytics.triggerInAppMessagesForSessionStart();
    };
    LocalyticsAndroid.dismissCurrentInAppMessage = function () {
        Localytics.dismissCurrentInAppMessage();
    };
    LocalyticsAndroid.setInAppMessageConfiguration = function (config) {
        if (LocalyticsAndroid.messagingListener != null) {
            LocalyticsAndroid.messagingListener.setInAppConfiguration(config);
        }
        else {
            Log.i(LocalyticsAndroid.LOG_TAG, 'Call to setInAppMessagingConfiguration failed; Messaging Listener is null. Call setMessagingListener before setting configuration');
            throw new Error('Messaging Listener is null. Call setMessagingListener before setting configuration');
        }
    };
    LocalyticsAndroid.isInAppAdIdParameterEnabled = function () {
        return Localytics.isAdidAppendedToInAppUrls();
    };
    LocalyticsAndroid.setInAppAdIdParameterEnabled = function (enabled) {
        Localytics.appendAdidToInAppUrls(enabled);
    };
    LocalyticsAndroid.isInboxAdIdParameterEnabled = function () {
        return Localytics.isAdidAppendedToInboxUrls();
    };
    LocalyticsAndroid.setInboxAdIdParameterEnabled = function (enabled) {
        Localytics.appendAdidToInboxUrls(enabled);
    };
    LocalyticsAndroid.getDisplayableInboxCampaigns = function () {
        var campaigns = Localytics.getDisplayableInboxCampaigns();
        var nsCampaigns = [];
        for (var _i = 0, campaigns_1 = campaigns; _i < campaigns_1.length; _i++) {
            var campaign = campaigns_1[_i];
            LocalyticsAndroid.inboxCampaignCache[campaign.getCampaignId()] = campaign;
            nsCampaigns.push(util_1.toInboxJSON(campaign));
        }
        return nsCampaigns;
    };
    LocalyticsAndroid.getAllInboxCampaigns = function () {
        var campaigns = Localytics.getAllInboxCampaigns();
        var nsCampaigns = [];
        for (var _i = 0, campaigns_2 = campaigns; _i < campaigns_2.length; _i++) {
            var campaign = campaigns_2[_i];
            LocalyticsAndroid.inboxCampaignCache[campaign.getCampaignId()] = campaign;
            nsCampaigns.push(util_1.toInboxJSON(campaign));
        }
        return nsCampaigns;
    };
    LocalyticsAndroid.refreshInboxCampaigns = function () {
        throw new Error('Not yet implemented');
    };
    LocalyticsAndroid.refreshAllInboxCampaigns = function () {
        throw new Error('Not yet implemented');
    };
    LocalyticsAndroid.setInboxCampaignRead = function (campaignId, read) {
        var campaign = LocalyticsAndroid.inboxCampaignCache[campaignId];
        if (campaign != null) {
            Localytics.setInboxCampaignRead(campaign, read);
            LocalyticsAndroid.updateInboxCampaignCache();
        }
        else {
            Log.i(LocalyticsAndroid.LOG_TAG, "Call to setInboxCampaignRead failed; Couldn't find Inbox campaign with ID " + campaignId);
            throw new Error("Couldn't find Inbox campaign with ID " + campaignId);
        }
    };
    LocalyticsAndroid.deleteInboxCampaign = function (campaignId) {
        var campaign = LocalyticsAndroid.inboxCampaignCache[campaignId];
        if (campaign != null) {
            Localytics.deleteInboxCampaign(campaign);
            LocalyticsAndroid.updateInboxCampaignCache();
        }
        else {
            Log.i(LocalyticsAndroid.LOG_TAG, "Call to deleteInboxCampaign failed; Couldn't find Inbox campaign with ID " + campaignId);
            throw new Error("Couldn't find Inbox campaign with ID " + campaignId);
        }
    };
    LocalyticsAndroid.getInboxCampaignsUnreadCount = function () {
        return Localytics.getInboxCampaignsUnreadCount();
    };
    LocalyticsAndroid.inboxListItemTapped = function (campaignId) {
        var campaign = LocalyticsAndroid.inboxCampaignCache[campaignId];
        if (campaign != null) {
            Localytics.inboxListItemTapped(campaign);
            LocalyticsAndroid.updateInboxCampaignCache();
        }
        else {
            Log.i(LocalyticsAndroid.LOG_TAG, "Call to inboxListItemTapped failed; Couldn't find Inbox campaign with ID " + campaignId);
            throw new Error("Couldn't find Inbox campaign with ID " + campaignId);
        }
    };
    LocalyticsAndroid.triggerPlacesNotification = function (campaignId) {
        var campaign = LocalyticsAndroid.placesCampaignCache[campaignId];
        if (campaign != null) {
            Localytics.triggerPlacesNotification(campaign);
        }
        else {
            Log.i(LocalyticsAndroid.LOG_TAG, "Call to triggerPlacesNotification failed; Couldn't find Places campaign with ID " + campaignId);
            throw new Error("Couldn't find Inbox campaign with ID " + campaignId);
        }
    };
    LocalyticsAndroid.setPlacesMessageConfiguration = function (config) {
        if (LocalyticsAndroid.messagingListener != null) {
            LocalyticsAndroid.messagingListener.setPlacesConfiguration(config);
        }
        else {
            Log.i(LocalyticsAndroid.LOG_TAG, 'Call to setPlacesMessagingConfiguration failed; Messaging Listener is null. Call setMessagingListener before setting configuration');
            throw new Error('Messaging Listener is null. Call setMessagingListener before setting configuration');
        }
    };
    LocalyticsAndroid.setMessagingListener = function (listener) {
        LocalyticsAndroid.messagingListener = new messagingListener_1.MessagingListenerV2Impl(listener, LocalyticsAndroid.inAppCampaignCache, LocalyticsAndroid.pushCampaignCache, LocalyticsAndroid.placesCampaignCache);
        Localytics.setMessagingListener(LocalyticsAndroid.messagingListener);
    };
    LocalyticsAndroid.removeMessagingListener = function () {
        LocalyticsAndroid.messagingListener = null;
        Localytics.setMessagingListener(null);
    };
    LocalyticsAndroid.setLocationMonitoringEnabled = function (enabled) {
        Localytics.setLocationMonitoringEnabled(enabled);
    };
    LocalyticsAndroid.getGeofencesToMonitor = function (latitude, longitude) {
        var circularRegions = Localytics.getGeofencesToMonitor(latitude, longitude);
        var nsCircularRegions = [];
        for (var _i = 0, circularRegions_1 = circularRegions; _i < circularRegions_1.length; _i++) {
            var circularRegion = circularRegions_1[_i];
            nsCircularRegions.push(util_1.toCircularRegionJSON(circularRegion));
        }
        return nsCircularRegions;
    };
    LocalyticsAndroid.triggerRegion = function (region, event, latitude, longitude) {
        throw new Error('Not yet implemented');
    };
    LocalyticsAndroid.triggerRegions = function (regions, event, latitude, longitude) {
        throw new Error('Not yet implemented');
    };
    LocalyticsAndroid.setLocationListener = function (listener) {
        throw new Error('Not yet implemented');
    };
    LocalyticsAndroid.removeLocationListener = function () {
        throw new Error('Not yet implemented');
    };
    LocalyticsAndroid.setCallToActionListener = function (listener) {
        throw new Error('Not yet implemented');
    };
    LocalyticsAndroid.removeCallToActionListener = function () {
        throw new Error('Not yet implemented');
    };
    LocalyticsAndroid.setLoggingEnabled = function (enabled) {
        Localytics.setLoggingEnabled(enabled);
    };
    LocalyticsAndroid.isLoggingEnabled = function () {
        return Localytics.isLoggingEnabled();
    };
    LocalyticsAndroid.setOptions = function (options) {
        Localytics.setOptions(util_1.toHashMap(options));
    };
    LocalyticsAndroid.setOption = function (key, value) {
        Localytics.setOption(key, value);
    };
    LocalyticsAndroid.redirectLogsToDisk = function (writeExternally) {
        Localytics.redirectLogsToDisk(writeExternally, application.android.foregroundActivity);
    };
    LocalyticsAndroid.getInstallId = function () {
        return Localytics.getInstallId();
    };
    LocalyticsAndroid.getAppKey = function () {
        return Localytics.getAppKey();
    };
    LocalyticsAndroid.getLibraryVersion = function () {
        return Localytics.getLibraryVersion();
    };
    LocalyticsAndroid.updateInboxCampaignCache = function () {
        for (var _i = 0, _a = Localytics.getAllInboxCampaigns(); _i < _a.length; _i++) {
            var campaign = _a[_i];
            LocalyticsAndroid.inboxCampaignCache[campaign.getCampaignId()] = campaign;
        }
    };
    LocalyticsAndroid.LOG_TAG = 'Localytics-NativeScript';
    LocalyticsAndroid.inboxCampaignCache = new Array();
    LocalyticsAndroid.inAppCampaignCache = new Array();
    LocalyticsAndroid.pushCampaignCache = new Array();
    LocalyticsAndroid.placesCampaignCache = new Array();
    LocalyticsAndroid.analyticsListener = null;
    LocalyticsAndroid.messagingListener = null;
    return LocalyticsAndroid;
}());
exports.Localytics = LocalyticsAndroid;
//# sourceMappingURL=localytics.android.js.map